pub enum ArgumentValue {
Scope(Scopes),
Item(Item),
ScopeOrItem(Scopes, Item),
TraitTrack,
Modif,
Identifier(&'static str),
UncheckedValue,
Removed(&'static str, &'static str),
}Expand description
A description of the constraints on a value with a prefix such as var: or list_size:
Variants
Scope(Scopes)
The value must be an expression that resolves to a scope object of the given type.
Item(Item)
The value must be the name of an item of the given item type.
ScopeOrItem(Scopes, Item)
The value can be either a Scope or an Item
TraitTrack
The value can be a trait name or trait|track.
Modif
The value must be the name of a modif
Identifier(&'static str)
The value must be a single word
UncheckedValue
The value can be anything
Removed(&'static str, &'static str)
This trigger no longer exists. Arguments are version and explanation