pub fn needs_prefix(
arg: &str,
data: &Everything,
scopes: Scopes,
) -> Option<&'static str>Expand description
Look up a token that’s an invalid target, and see if it might be missing a prefix. Return the prefix if one was found.
scopes should be a singular Scopes flag.
Example: if the token is “irish” and scopes is Scopes::Culture then return
Some("culture") to indicate that the token should have been “culture:irish”.