pub fn scope_to_scope(
name: &Token,
inscopes: Scopes,
) -> Option<(Scopes, Scopes)>Expand description
Look up an “event link”, which is a script token that looks up something related to a scope value and returns another scope value.
name is the token. inscopes is the known scope context of this token.
inscopes is only used for some special-case event links whose output scope type
depends on their input scope type.
Returns a pair of Scopes. The first is the scope types this token can accept as input,
and the second is the scope types it may return.