Scopes

Struct Scopes 

pub struct Scopes(<Scopes as PublicFlags>::Internal);
This type represents our knowledge about the set of scope types that a script value can have. In most cases it’s narrowed down to a single scope type, but not always.

The available scope types depend on the game. They are listed in event_scopes.log from the game data dumps.

Tuple Fields

0: <Scopes as PublicFlags>::Internal

Implementations

Source

impl Scopes

pub const None: Self

pub const Value: Self

pub const Bool: Self

pub const Flag: Self

pub const Color: Self

pub const Country: Self

pub const Character: Self

pub const Culture: Self

pub const Province: Self

pub const Pop: Self

pub const Party: Self

pub const Religion: Self

pub const State: Self

pub const War: Self

pub const StrategicRegion: Self

pub const Decision: Self

pub const Accolade: Self

pub const AccoladeType: Self

pub const Activity: Self

pub const ActivityType: Self

pub const Army: Self

pub const Artifact: Self

pub const CasusBelli: Self

pub const CharacterMemory: Self

pub const Combat: Self

pub const CombatSide: Self

pub const CouncilTask: Self

pub const CulturePillar: Self

pub const CultureTradition: Self

pub const Doctrine: Self

pub const Dynasty: Self

pub const DynastyHouse: Self

pub const Faction: Self

pub const Faith: Self

pub const GovernmentType: Self

pub const GreatHolyWar: Self

pub const HolyOrder: Self

pub const Inspiration: Self

pub const LandedTitle: Self

pub const MercenaryCompany: Self

pub const Scheme: Self

pub const Secret: Self

pub const StoryCycle: Self

pub const Struggle: Self

pub const TitleAndVassalChange: Self

pub const Trait: Self

pub const TravelPlan: Self

pub const VassalContract: Self

pub const VassalObligationLevel: Self

pub const HoldingType: Self

pub const TaxSlot: Self

pub const EpidemicType: Self

pub const Epidemic: Self

pub const LegendType: Self

pub const Legend: Self

pub const GeographicalRegion: Self

pub const Domicile: Self

pub const AgentSlot: Self

pub const TaskContract: Self

pub const TaskContractType: Self

pub const Regiment: Self

pub const CasusBelliType: Self

pub const CourtPosition: Self

pub const CourtPositionType: Self

pub const Situation: Self

pub const SituationParticipantGroup: Self

pub const SituationSubRegion: Self

pub const Confederation: Self

pub const HouseAspiration: Self

pub const HouseRelation: Self

pub const HouseRelationType: Self

pub const HouseRelationLevel: Self

pub const ConfederationType: Self

pub const GreatProject: Self

pub const ProjectContribution: Self

pub const CultureInnovation: Self

pub const GreatProjectType: Self

pub const Battle: Self

pub const BattleSide: Self

pub const Building: Self

pub const BuildingType: Self

pub const CharacterRole: Self

pub const CivilWar: Self

pub const CulturalCommunity: Self

pub const NewCombatUnit: Self

pub const CommanderOrderType: Self

pub const CountryCreation: Self

pub const CountryDefinition: Self

pub const CountryFormation: Self

pub const Decree: Self

pub const DiplomaticAction: Self

pub const DiplomaticPact: Self

pub const DiplomaticPlay: Self

pub const DiplomaticRelations: Self

pub const Front: Self

pub const Goods: Self

pub const Hq: Self

pub const Ideology: Self

pub const Institution: Self

pub const InstitutionType: Self

pub const InterestMarker: Self

pub const InterestGroup: Self

pub const InterestGroupTrait: Self

pub const InterestGroupType: Self

pub const JournalEntry: Self

pub const Law: Self

pub const LawType: Self

pub const Market: Self

pub const MarketGoods: Self

pub const Objective: Self

pub const PoliticalMovement: Self

pub const PopType: Self

pub const ShippingLanes: Self

pub const StateRegion: Self

pub const StateTrait: Self

pub const Technology: Self

pub const TechnologyStatus: Self

pub const Theater: Self

pub const CombatUnitType: Self

pub const MilitaryFormation: Self

pub const Sway: Self

pub const StateGoods: Self

pub const DiplomaticDemand: Self

pub const Company: Self

pub const CompanyType: Self

pub const TravelNode: Self

pub const TravelNodeDefinition: Self

pub const TravelConnection: Self

pub const TravelConnectionDefinition: Self

pub const Invasion: Self

pub const MobilizationOption: Self

pub const PowerBlocPrincipleGroup: Self

pub const DiplomaticPlayType: Self

pub const DiplomaticCatalyst: Self

pub const DiplomaticCatalystType: Self

pub const DiplomaticCatalystCategory: Self

pub const PoliticalLobby: Self

pub const PoliticalLobbyType: Self

pub const PoliticalLobbyAppeasement: Self

pub const PowerBloc: Self

pub const PowerBlocIdentity: Self

pub const PowerBlocPrinciple: Self

pub const HarvestCondition: Self

pub const PoliticalMovementType: Self

pub const HarvestConditionType: Self

pub const TreatyArticle: Self

pub const TreatyOptions: Self

pub const TreatyArticleOptions: Self

pub const Treaty: Self

pub const BuildingGroup: Self

pub const Amendment: Self

pub const AmendmentType: Self

pub const GeographicRegion: Self

pub const WarGoal: Self

pub const WarGoalType: Self

pub const InterestTierType: Self

pub const NavalBattle: Self

pub const NavalMission: Self

pub const NavalMissionType: Self

pub const Ship: Self

pub const ShipGroup: Self

pub const ShipModificationType: Self

pub const ShipType: Self

pub const Strait: Self

pub const StraitType: Self

pub const Area: Self

pub const CountryCulture: Self

pub const CultureGroup: Self

pub const Deity: Self

pub const Family: Self

pub const Governorship: Self

pub const GreatWork: Self

pub const Job: Self

pub const Legion: Self

pub const LevyTemplate: Self

pub const Region: Self

pub const Siege: Self

pub const SubUnit: Self

pub const Treasure: Self

pub const Unit: Self

Source

impl Scopes

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u128

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u128) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u128) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u128) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in self are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in other are also set in self.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in other are also set in self.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in self and other.

pub fn remove(&mut self, other: Self)

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in self and other.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in self and other.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in self and other.

pub const fn difference(self, other: Self) -> Self

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in self and other.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in self, truncating the result.

Source

impl Scopes

pub const fn iter(&self) -> Iter<Scopes>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<Scopes>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl Scopes

pub const fn non_primitive() -> Scopes

pub const fn primitive() -> Scopes

pub const fn all_but_none() -> Scopes

pub fn from_snake_case(s: &str) -> Option<Scopes>

Read a scope type in string form and return it as a Scopes value.

pub fn from_snake_case_multi(s: &str) -> Option<Scopes>

Similar to from_snake_case, but allows multiple scopes separated by | Returns None if any of the conversions fail.